# Datasets

## Base Classes

::: flyvis.datasets.datasets.SequenceDataset

::: flyvis.datasets.datasets.StimulusDataset

::: flyvis.datasets.datasets.MultiTaskDataset

## Flashes

::: flyvis.datasets.flashes.Flashes

## Moving Bar

::: flyvis.datasets.moving_bar.MovingBar

## Impulses

::: flyvis.datasets.dots.Dots

::: flyvis.datasets.dots.SpatialImpulses

::: flyvis.datasets.dots.CentralImpulses

## Sintel

::: flyvis.datasets.sintel.MultiTaskSintel
